pub struct Rating(pub u8);Expand description
The user’s rating of the song or piece, from 1 (lowest) to 10 (highest).
Tuple Fields
0: u8Trait Implementations
Sourceimpl AsXml for Rating
impl AsXml for Rating
Sourcetype ItemIter<'xso_proc_as_xml_iter_lifetime> = RatingAsXmlIterator<'xso_proc_as_xml_iter_lifetime>
where
Self: 'xso_proc_as_xml_iter_lifetime
type ItemIter<'xso_proc_as_xml_iter_lifetime> = RatingAsXmlIterator<'xso_proc_as_xml_iter_lifetime> where Self: 'xso_proc_as_xml_iter_lifetime
The iterator type. Read more
impl Eq for Rating
Sourceimpl FromXml for Rating
impl FromXml for Rating
Sourcefn from_events(
name: QName,
attrs: AttrMap,
ctx: &Context<'_>,
) -> Result<Self::Builder, FromEventsError>
fn from_events( name: QName, attrs: AttrMap, ctx: &Context<'_>, ) -> Result<Self::Builder, FromEventsError>
Attempt to initiate the streamed construction of this struct from XML. Read more
Sourcefn xml_name_matcher() -> XmlNameMatcher<'static>
fn xml_name_matcher() -> XmlNameMatcher<'static>
Return a predicate which determines if
Self may be parsed from
a given XML element. Read moreimpl StructuralPartialEq for Rating