pub struct Uri(pub String);Expand description
A URI or URL pointing to information about the song, collection, or artist.
Tuple Fields
0: StringTrait Implementations
Sourceimpl AsXml for Uri
impl AsXml for Uri
Sourcetype ItemIter<'xso_proc_as_xml_iter_lifetime> = UriAsXmlIterator<'xso_proc_as_xml_iter_lifetime>
where
Self: 'xso_proc_as_xml_iter_lifetime
type ItemIter<'xso_proc_as_xml_iter_lifetime> = UriAsXmlIterator<'xso_proc_as_xml_iter_lifetime> where Self: 'xso_proc_as_xml_iter_lifetime
The iterator type. Read more
impl Eq for Uri
Sourceimpl FromXml for Uri
impl FromXml for Uri
Sourcefn from_events(
name: QName,
attrs: AttrMap,
ctx: &Context<'_>,
) -> Result<Self::Builder, FromEventsError>
fn from_events( name: QName, attrs: AttrMap, ctx: &Context<'_>, ) -> Result<Self::Builder, FromEventsError>
Attempt to initiate the streamed construction of this struct from XML. Read more
Sourcefn xml_name_matcher() -> XmlNameMatcher<'static>
fn xml_name_matcher() -> XmlNameMatcher<'static>
Return a predicate which determines if
Self may be parsed from
a given XML element. Read moreimpl StructuralPartialEq for Uri